function B=chunk(A,n,step)
% CHUNK: return chunk from inside matrix
% B=chunk(A,n,hop): returns nth block of rows of size hop from A
% A:  source matrix
% n:  index of chunk
% hop: size of chunk

i=n*step+1;
B=A(i:i+step-1,:);


